Fonts
Fonts
CountFontsAsync
Returns a number of fonts in a subscription
Request
GET /api/v1/fonts/count[?subscriptionId]
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| subscriptionId | string | subscripiton id |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Everything is all right |
|
| 400 | id is not hex24 |
|
| 402 | Subscription is outdated |
|
| 403 | You don't have permission to get fonts from this subscription (or in your default (1st) subscription) |
|
| 404 | there is no subscription with provided id found, or user don't even have a subscription |
CountPublicFontsAsync
Returns a number of pulbic fonts
Request
GET /api/v1/fonts/public/count
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Everything is all right |
|
| 402 | Subscription is outdated |
|
| 403 | You don't have permission to get fonts from this subscription (or in your default (1st) subscription) |
|
| 404 | there is no subscription with provided id found, or user don't even have a subscription |
AddPublicFont
Allows user to add a font from a list of public fonts to their subscription
Request
POST /api/v1/fonts/add
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| body | a body with font id and workspace id |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Success |
|
| 400 | Bad Request |
|
| 402 | Client Error |
|
| 403 | Forbidden |
|
| 404 | Not Found |
UploadFont
Allows user to upload a new truetype font to their subscription
Request
POST /api/v1/fonts/upload
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| File | file | ||
| SubscriptionId | string | ||
| Enabled | boolean |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Success |
|
| 400 | Bad Request |
|
| 402 | Client Error |
|
| 403 | Forbidden |
|
| 404 | Not Found |
GetPublicFonts
Returns a list of public fonts
Request
GET /api/v1/fonts/public/list[?skip&take]
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| skip | integer | 0 | |
| take | integer | 10 |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Success |
GetFonts
returns a list of fonts in the subscription
Request
GET /api/v1/fonts/list[?subscriptionId&skip&take]
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| subscriptionId | string | id of a subscription, to pull the fonts from. If null, only the public fonts will be returned |
|
| skip | integer | 0 | how many fonts to skip |
| take | integer | 10 | how many fonts to take |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Success |
|
| 400 | Bad Request |
|
| 403 | Forbidden |
|
| 404 | Not Found |
GetFontsByReport
Returns a list of fonts in the subscription by report id.
Request
GET /api/v1/fonts/ListByReport/{reportId}[?skip&take]
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *reportId | string | id of a report |
|
| skip | integer | 0 | how many fonts to skip |
| take | integer | 10 | how many fonts to take |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Success |
|
| 400 | Bad Request |
|
| 403 | Forbidden |
|
| 404 | Not Found |
GetFontsByTemplate
Returns a list of fonts in the subscription by report id.
Request
GET /api/v1/fonts/ListByTemplate/{templateId}[?skip&take]
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *templateId | string | id of a report |
|
| skip | integer | 0 | how many fonts to skip |
| take | integer | 10 | how many fonts to take |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Success |
|
| 400 | Bad Request |
|
| 403 | Forbidden |
|
| 404 | Not Found |
GetFontFamilies
Returns distinct font names from public and private font lists (excluding disabled fonts)
Request
GET /api/v1/fonts/families[?subscriptionId&skip&take]
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| subscriptionId | string | id of a subscription, to pull the font names from. If null or the subscription has no fonts, only the public fonts will be returned |
|
| skip | integer | 0 | how many names to skip |
| take | integer | 10 | how many namrs to take |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Success |
|
| 400 | Bad Request |
|
| 404 | Not Found |
DownloadFont
Downloads font by it's id
Request
GET /api/v1/fonts/{id}/download
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *id | string | id of the font |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Success |
|
| 404 | Not Found |
|
| 400 | Bad Request |
|
| 402 | Client Error |
|
| 403 | Forbidden |
DeleteFont
deletes a font from the subscirption by id
Request
DELETE /api/v1/fonts/{id}
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *id | string | font id |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 204 | No Content |
|
| 400 | Bad Request |
|
| 402 | Client Error |
|
| 403 | Forbidden |
|
| 404 | Not Found |
UpdateFont
updates a user font model
Request
PUT /api/v1/fonts/{id}
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *id | string | id of the font |
|
| body | update VM body |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 201 | Created |
|
| 400 | Bad Request |
|
| 402 | Client Error |
|
| 403 | Forbidden |
|
| 404 | Not Found |
DownloadPublicFont
Downloads a public font by it's id
Request
GET /api/v1/fonts/public/{id}/download
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *id | string | id of the font |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Success |
|
| 404 | Not Found |
GetPublicFontsCss
Creates a css stylesheet for a public font
Request
GET /api/v1/fonts/public/css
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Success |
CountOccupiedSpace
returns storage space occupied by fonts in the subscription
Request
GET /api/v1/fonts/counttotalsizebysubscription[?subscriptionId]
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| subscriptionId | string | subscription id |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Success |
|
| 400 | Bad Request |
|
| 402 | Client Error |
|
| 403 | Forbidden |
|
| 404 | Not Found |
GetPermissions
Get font's permissions
Request
GET /api/v1/fonts/{id}/permissions
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *id | string | user font id |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Success |
|
| 400 | Bad Request |
|
| 402 | Client Error |
|
| 403 | Forbidden |
|
| 404 | Not Found |
|
| 500 | Server Error |
UpdatePermissions
Update permissions
Request
PUT /api/v1/fonts/{id}/permissions
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *id | string | ||
| body |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Success |
|
| 400 | Bad Request |
|
| 402 | Client Error |
|
| 403 | Forbidden |
|
| 404 | Not Found |
|
| 500 | Server Error |
GetMyPermissions
Get current user's permissions to a font
Request
GET /api/v1/fonts/{id}/mypermissions
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *id | string | user font id |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | got permissions successfully |
|
| 400 | The request is wrong |
|
| 404 | There is no font or a subscription with provided id found |
GetFontsCss
Creates a css stylesheet for a public font
Request
GET /api/v1/fonts/css[?subscriptionId]
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| subscriptionId | string |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Success |
|
| 400 | Bad Request |
|
| 402 | Client Error |
|
| 403 | Forbidden |
GetFontsCssByReport
Creates a css stylesheet for a public fonts by report.
Request
GET /api/v1/fonts/CssByReport/{reportId}
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *reportId | string | id of a report |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Success |
|
| 400 | Bad Request |
|
| 403 | Forbidden |
|
| 404 | Not Found |
GetFontsCssByTemplate
Creates a css stylesheet for a public font by template.
Request
GET /api/v1/fonts/CssByTemplate/{templateId}
Parameters
| Name | Type | Value | Notes |
|---|---|---|---|
| *templateId | string | id of a report |
Responses
| Status Code | Description | Samples |
|---|---|---|
| 200 | Success |
|
| 400 | Bad Request |
|
| 403 | Forbidden |
|
| 404 | Not Found |
Definitions
CountVM
| Name | Type | Notes |
|---|---|---|
| count | integer (int64) | |
| $t | string |
ProblemDetails
| Name | Type | Notes |
|---|---|---|
| type | string | |
| title | string | |
| status | integer (int32) | |
| detail | string | |
| instance | string |
AddPublicFontVM
| Name | Type | Notes |
|---|---|---|
| fontId | string | |
| subscriptionId | string | |
| $t | string |
UserFontVM
| Name | Type | Notes |
|---|---|---|
| id | string | |
| enabled | boolean | |
| font |
|
|
| createdTime | string (date-time) | |
| creatorUserId | string | |
| editedTime | string (date-time) | |
| editorUserId | string | |
| description | string | |
| subscriptionId | string | |
| size | integer (int64) | |
| $t | string |
FontVM
| Name | Type | Notes |
|---|---|---|
| id | string | |
| name | string | |
| postScriptName | string | |
| names | array | |
| weight | integer (int32) | |
| italic | boolean | |
| publiclyAccessible | boolean | |
| createdTime | string (date-time) | |
| creatorUserId | string | |
| editedTime | string (date-time) | |
| editorUserId | string | |
| $t | string |
UserFontsVM
| Name | Type | Notes |
|---|---|---|
| skip | integer (int32) | |
| take | integer (int32) | |
| count | integer (int64) | |
| fonts |
|
|
| $t | string |
FontsVM
| Name | Type | Notes |
|---|---|---|
| skip | integer (int32) | |
| take | integer (int32) | |
| count | integer (int64) | |
| fonts |
|
|
| $t | string |
FontNamesVM
| Name | Type | Notes |
|---|---|---|
| names | array | |
| $t | string |
UpdateUserFontVM
| Name | Type | Notes |
|---|---|---|
| enabled | boolean | |
| description | string | |
| $t | string |
FontSizeVM
| Name | Type | Notes |
|---|---|---|
| size | integer (int64) | |
| $t | string |
UserFontPermissionsVM
| Name | Type | Notes |
|---|---|---|
| permissions |
|
|
| $t | string |
UserFontPermissionsCRUDVM
| Name | Type | Notes |
|---|---|---|
| ownerId | string | |
| owner |
|
|
| groups | object | |
| other |
|
|
| anon |
|
|
| $t | string |
UserFontPermissionCRUDVM
| Name | Type | Notes |
|---|---|---|
| create |
|
|
| delete |
|
|
| execute |
|
|
| get |
|
|
| update |
|
|
| administrate |
|
|
| $t | string |
FontCreate
FontDelete
FontExecute
FontGet
FontUpdate
FontAdministrate
UpdateUserFontPermissionsVM
| Name | Type | Notes |
|---|---|---|
| newPermissions |
|
|
| administrate |
|
|
| $t | string |